﻿using System;
using System.Collections.Generic;
using System.Drawing;
using Infragistics;

using MonoTouch.Foundation;
using MonoTouch.UIKit;

namespace PieChartTheme
{
	public partial class _40395PieChartThemeViewController : UIViewController
	{

		IGPieChartView _infraPieChart;
		IGPieChartViewDataSourceHelper _source;
		IGLegend _legend;
		List<NSObject> _data;

		static bool UserInterfaceIdiomIsPhone {
			get { return UIDevice.CurrentDevice.UserInterfaceIdiom == UIUserInterfaceIdiom.Phone; }
		}

		public _40395PieChartThemeViewController (IntPtr handle) : base (handle)
		{
		}

		public override void DidReceiveMemoryWarning ()
		{
			// Releases the view if it doesn't have a superview.
			base.DidReceiveMemoryWarning ();
			
			// Release any cached data, images, etc that aren't in use.
		}

		#region View lifecycle

		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();
			_data = this.CreateSimpleData(9);
			_source = new IGPieChartViewDataSourceHelper(_data.ToArray(), "value", "label");
			_infraPieChart = new IGPieChartView();
			_infraPieChart.Frame = new RectangleF(0, 50, this.View.Frame.Size.Width, this.View.Frame.Size.Height - 50);
			_infraPieChart.AutoresizingMask = UIViewAutoresizing.FlexibleWidth|UIViewAutoresizing.FlexibleHeight;
			_infraPieChart.DataSource = _source;
			_infraPieChart.Theme = IGPieChartDefaultThemes.IGThemeDark();
			_infraPieChart.BackgroundColor = UIColor.Clear;
			_infraPieChart.OthersCategoryType = IGOthersCategoryType.IGOthersCategoryTypeNumber;
			_infraPieChart.OthersCategoryThreshold = 0;
			_infraPieChart.Theme = CreateThemePieChart10Colors ();

			//_infraPieChart.Brushes = GetBrushes ();

			this.View.AddSubview(_infraPieChart);
			IGLegend legend = new IGLegend(IGChartLegendType.IGChartLegendTypeItem);
			legend.Layer.BorderColor = UIColor.Gray.CGColor;
			legend.Layer.BorderWidth = 2;
			legend.Frame = new RectangleF(5, 5, this.View.Frame.Size.Width - 10, 45);
			legend.AutoresizingMask = UIViewAutoresizing.FlexibleWidth|UIViewAutoresizing.FlexibleBottomMargin;
			legend.HorizontalAlignment = IGHorizontalAlign.IGHorizontalAlignStretch;
			legend.VerticalAlignment = IGVerticalAlign.IGVerticalAlignCenter;
			legend.Orientation = IGOrientation.IGOrientationHorizontal;
			legend.Layer.CornerRadius = 8;
			legend.Layer.MasksToBounds = true;
			_infraPieChart.Legend = legend;
			this.View.AddSubview(legend);


			// Perform any additional setup after loading the view, typically from a nib.
		}

		public override void ViewWillAppear (bool animated)
		{
			base.ViewWillAppear (animated);
		}

		public override void ViewDidAppear (bool animated)
		{
			base.ViewDidAppear (animated);
		}

		public override void ViewWillDisappear (bool animated)
		{
			base.ViewWillDisappear (animated);
		}

		public override void ViewDidDisappear (bool animated)
		{
			base.ViewDidDisappear (animated);
		}

		List<NSObject> CreateSimpleData(int recordCount)
		{
			List<NSObject> retValue = new List<NSObject>();
			for (int i = 0; i < recordCount; i++) {
				SimpleData data = new SimpleData(i, string.Format("Slice {0}", i));
				retValue.Add(data);
			}

			return retValue;
		} 

		NSObject[] GetBrushes()
		{
			NSObject[] brushes = new NSObject[8];
			brushes [0] = new IGBrush (UIColor.Blue);
			brushes [1] = new IGBrush (UIColor.Brown);
			brushes [2] = new IGBrush (UIColor.Cyan);
			brushes [3] = new IGBrush (UIColor.DarkGray);
			brushes [4] = new IGBrush (UIColor.DarkTextColor);
			brushes [5] = new IGBrush (UIColor.Green);
			brushes [6] = new IGBrush (UIColor.Magenta);
			brushes [7] = new IGBrush (UIColor.Orange);
			return brushes;
		}

		public IGPieChartThemeDefinition CreateThemePieChart10Colors()
		{
			IGPieChartThemeDefinition def = new IGPieChartThemeDefinition();
			def.Font = UIFont.FromName("Helvetica", 12);
			def.FontColor = new IGBrush(0, 0, 0, 1);
			def.BackgroundColor = UIColor.White;
			def.LegendFont = UIFont.FromName("Helvetica", 12);
			def.LegendFontColor = new IGBrush(0, 0, 0, 1);
			def.LegendBorderThickness = 1;
			def.LegendPalette = new IGChartPaletteItem();
			def.LegendPalette.Color = new IGBrush(0.9f, 0.9f, 0.9f, 0.8f);
			def.LegendPalette.OutlineColor = new IGBrush(0.7f, 0.7f, 0.7f, 1f);
			IGChartPaletteItem item1 = new IGChartPaletteItem();
			item1.OutlineColor = new IGBrush(0.69f, 0.75f, 0.79f, 1f);
			item1.Color = new IGBrush(0.31f, 0.65f, 0.74f, 1f);
			(def.SlicePalettes).Add(item1);
			IGChartPaletteItem item2 = new IGChartPaletteItem();
			item2.OutlineColor = new IGBrush(0.47f, 0.53f, 0.58f, 1f);
			item2.Color = new IGBrush(0.98f, 0.40f, 0.33f, 1f);
			(def.SlicePalettes).Add(item2);
			IGChartPaletteItem item3 = new IGChartPaletteItem();
			item3.OutlineColor = new IGBrush(0.31f, 0.38f, 0.42f, 1f);
			item3.Color = new IGBrush(0.99f, 0.76f, 0.23f, 1f);
			(def.SlicePalettes).Add(item3);
			IGChartPaletteItem item4 = new IGChartPaletteItem();
			item4.OutlineColor = new IGBrush(0.21f, 0.27f, 0.31f, 1f);
			item4.Color = new IGBrush(0.23f, 0.39f, 0.6f, 1f);
			(def.SlicePalettes).Add(item4);
			IGChartPaletteItem item5 = new IGChartPaletteItem();
			item5.OutlineColor = new IGBrush(0.08f, 0.17f, 0.23f, 1f);
			item5.Color = new IGBrush(0.57f, 0.69f, 0.29f, 1f);
			(def.SlicePalettes).Add(item5);
			IGChartPaletteItem others = new IGChartPaletteItem();
			others.OutlineColor = new IGBrush(0.50f, 0.50f, 0.50f, 1f);
			others.Color = new IGBrush(0.33f, 0.05f, 1.0f, 1f);
			def.OthersCategoryFont = UIFont.FromName("Helvetica", 12);
			def.OthersCategoryFontColor = new IGBrush(0, 0, 0, 1);
			def.OthersCategoryThickness = 1.0f;
			def.OthersCategoryPalette = others;
			IGChartPaletteItem selected = new IGChartPaletteItem();
			selected.OutlineColor = new IGBrush(0.50f, 0.50f, 0.50f, 1f);
			selected.Color = new IGBrush(0.16f, 0.81f, 1f, 1f);
			def.SelectedFont = UIFont.FromName("Helvetica", 12);
			def.SelectedFontColor = new IGBrush(0, 0, 0, 1);
			def.SelectedThickness = 1.0f;
			def.SelectedPalette = selected;
			IGChartPaletteItem leaderLine = new IGChartPaletteItem();
			leaderLine.OutlineColor = new IGBrush(0.10f, 0.10f, 0.10f, 1f);
			leaderLine.Color = new IGBrush(0.10f, 0.10f, 0.10f, 1f);
			def.LeaderLineThickness = 1.0f;
			def.LeaderLinePalette = leaderLine;

			return def;
		}

		#endregion
	}

	public class SimpleData : NSObject
	{
		[Export("value")]
		public double value { get; set;}
		[Export("label")]
		public string label { get; set; }
		public SimpleData (double data_value, string data_label)
		{
			value = data_value;
			label = data_label;
		}
	}
}

